summaryrefslogtreecommitdiffstats
path: root/ash/launcher/launcher_button.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/launcher/launcher_button.h')
-rw-r--r--ash/launcher/launcher_button.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/ash/launcher/launcher_button.h b/ash/launcher/launcher_button.h
index e1278b8..91ceca1 100644
--- a/ash/launcher/launcher_button.h
+++ b/ash/launcher/launcher_button.h
@@ -53,10 +53,13 @@ class LauncherButton : public views::CustomButton {
public:
IconView();
virtual ~IconView();
- virtual bool HitTest(const gfx::Point& l) const OVERRIDE;
+
void set_icon_size(int icon_size) { icon_size_ = icon_size; }
int icon_size() const { return icon_size_; }
+ // views::View overrides.
+ virtual bool HitTest(const gfx::Point& l) const OVERRIDE;
+
private:
// Set to non-zero to force icons to be resized to fit within a square,
// while maintaining original proportions.
@@ -88,8 +91,13 @@ class LauncherButton : public views::CustomButton {
private:
class BarView;
- // Updates the parts of the button to reflect the current state_. This may
- // add or remove views, layout and paint.
+
+ // Returns true if the shelf is horizontal. If this returns false the shelf is
+ // vertical.
+ bool IsShelfHorizontal() const;
+
+ // Updates the parts of the button to reflect the current |state_| and
+ // alignment. This may add or remove views, layout and paint.
void UpdateState();
LauncherButtonHost* host_;